
Welcome to the Sudio 🎵
=======================

``sudio`` is an **Open-source**, **easy-to-use** digital audio processing library featuring both a **real-time**, **non-real-time** mix/edit platform.

.. raw:: html

   <br><br><br><br>
   <div align="center"> 🎵 <b>Sudio</b> is like a <b>budding musician</b> finding its rhythm. Your support can help it <b>compose a symphony</b>. 🎶</div>
   <br>


.. raw:: html

   <div style="text-align: center;">
       <a href="https://ko-fi.com/T6T5JXCVA">
           <img src="https://ko-fi.com/img/githubbutton_sm.svg" alt="ko-fi">
       </a>
   </div>


.. raw:: html

   <script src='https://storage.ko-fi.com/cdn/scripts/overlay-widget.js'></script>
   <script>
     kofiWidgetOverlay.draw('mrzahaki', {
       'type': 'floating-chat',
       'floating-chat.donateButton.text': 'Support me',
       'floating-chat.donateButton.background-color': '#2980b9',
       'floating-chat.donateButton.text-color': '#fff'
     });
   </script>
   <br><br><br><br>


.. include:: installation.rst
.. include:: start.rst


LICENCE
-------

Open Source (OSI approved): Apache License 2.0



.. toctree::
   :maxdepth: 10
   :caption: Contents

   installation
   start 
   core
   pipeline
   audiosys
   api/io_root
   io
   metadata
   stream
   types
   rateshift
   wrap
   Source code <https://github.com/mrzahaki/sudio>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`